import { Client, Events, MimeTypes } from './types';
/**
 * Options for the Nym mixnet client.
 * @property autoConvertStringMimeTypes - An array of mime types.
 * @example
 * ```typescript
 * const client = await createNymMixnetClient({
 *  autoConvertStringMimeTypes: [MimeTypes.ApplicationJson, MimeTypes.TextPlain],
 * });
 * ```
 */
export interface NymMixnetClientOptions {
    autoConvertStringMimeTypes?: string[] | MimeTypes[];
}
/**
 * The client for the Nym mixnet which gives access to client methods and event subscriptions.
 * Returned by the {@link createNymMixnetClient} function.
 *
 */
export interface NymMixnetClient {
    client: Client;
    events: Events;
}
/**
 * Create a client to send and receive traffic from the Nym mixnet.
 * @required
 * @returns
 * @example
 * ```typescript
 * const client = await createNymMixnetClient();
 * ```
 */
export declare const createNymMixnetClient: (options?: NymMixnetClientOptions) => Promise<NymMixnetClient>;
